@@ -7,6 +7,7 @@ import shlex
 import shutil
 import sys
 from subprocess import Popen, PIPE
+from requests import ConnectionError
 
 from .. import package_info
 from . import client
@@ -94,6 +95,23 @@ class InsightsClient(object):
         """
         return client.get_branch_info(self.config, self.connection)
 
+    @_net
+    def get_egg_url(self):
+        """
+        Get the proper url based on the configured egg release branch
+        """
+        if self.config.legacy_upload:
+            url = self.connection.base_url + '/platform' + constants.module_router_path
+        else:
+            url = self.connection.base_url + constants.module_router_path
+        logger.log(NETWORK, "GET %s", url)
+        response = self.session.get(url, timeout=self.config.http_timeout)
+        if response.status_code == 200:
+            return response.json()["url"]
+        else:
+            logger.warning("Unable to fetch egg url. Defaulting to /release")
+            return '/release'
+
     def fetch(self, force=False):
         """
             returns (dict): {'core': path to new egg, None if no update,
@@ -108,16 +126,17 @@ class InsightsClient(object):
         logger.debug("Beginning core fetch.")
 
         # guess the URLs based on what legacy setting is
+        egg_release = self.get_egg_url()
         egg_url = self.config.egg_path
         egg_gpg_url = self.config.egg_gpg_path
         if egg_url is None:
-            egg_url = '/v1/static/core/insights-core.egg'
+            egg_url = '/v1/static{0}/insights-core.egg'.format(egg_release)
             # if self.config.legacy_upload:
             #     egg_url = '/v1/static/core/insights-core.egg'
             # else:
             #     egg_url = '/static/insights-core.egg'
         if egg_gpg_url is None:
-            egg_gpg_url = '/v1/static/core/insights-core.egg.asc'
+            egg_gpg_url = '/v1/static{0}/insights-core.egg.asc'.format(egg_release)
             # if self.config.legacy_upload:
             #     egg_gpg_url = '/v1/static/core/insights-core.egg.asc'
             # else:
@@ -170,13 +189,18 @@ class InsightsClient(object):
         # If the etag was found and we are not force fetching
         # Then add it to the request
         logger.log(NETWORK, "GET %s", url)
-        if current_etag and not force:
-            logger.debug('Requesting new file with etag %s', current_etag)
-            etag_headers = {'If-None-Match': current_etag}
-            response = self.session.get(url, headers=etag_headers, timeout=self.config.http_timeout)
-        else:
-            logger.debug('Found no etag or forcing fetch')
-            response = self.session.get(url, timeout=self.config.http_timeout)
+        try:
+            if current_etag and not force:
+                logger.debug('Requesting new file with etag %s', current_etag)
+                etag_headers = {'If-None-Match': current_etag}
+                response = self.session.get(url, headers=etag_headers, timeout=self.config.http_timeout)
+            else:
+                logger.debug('Found no etag or forcing fetch')
+                response = self.session.get(url, timeout=self.config.http_timeout)
+        except ConnectionError as e:
+            logger.error(e)
+            logger.error('The Insights API could not be reached.')
+            return False
 
         # Debug information
         logger.debug('Status code: %d', response.status_code)
@@ -624,6 +648,12 @@ class InsightsClient(object):
             tags["group"] = self.config.group
             write_tags(tags)
 
+    def list_specs(self):
+        logger.info("For a full list of insights-core datasources, please refer to https://insights-core.readthedocs.io/en/latest/specs_catalog.html")
+        logger.info("The items in General Datasources can be selected for omission by adding them to the 'components' section of file-redaction.yaml")
+        logger.info("When specifying these items in file-redaction.yaml, they must be prefixed with 'insights.specs.default.DefaultSpecs.', i.e. 'insights.specs.default.DefaultSpecs.httpd_V'")
+        logger.info("This information applies only to Insights Core collection. To use Core collection, set core_collect=True in %s", self.config.conf)
+
 
 def format_config(config):
     # Log config except the password
