@@ -6,6 +6,8 @@ import copy
 import six
 import sys
 from six.moves import configparser as ConfigParser
+from distutils.version import LooseVersion
+from .utilities import get_version_info
 
 try:
     from .constants import InsightsConstants as constants
@@ -14,6 +16,24 @@ except:
 
 logger = logging.getLogger(__name__)
 
+
+def _core_collect_default():
+    '''
+    Core collection should be disabled by default, unless
+    the RPM version 3.1 or above
+    '''
+    rpm_version = get_version_info()['client_version']
+    if not rpm_version:
+        # problem getting the version, default to False
+        return False
+    if LooseVersion(rpm_version) < LooseVersion(constants.core_collect_rpm_version):
+        # rpm version is older than the core collection release
+        return False
+    else:
+        # rpm version is equal to or newer than the core collection release
+        return True
+
+
 DEFAULT_OPTS = {
     'analyze_container': {
         'default': False,
@@ -102,6 +122,9 @@ DEFAULT_OPTS = {
         'help': 'Pass a custom config file',
         'action': 'store'
     },
+    'core_collect': {
+        'default': False
+    },
     'egg_path': {
         # non-CLI
         'default': None
@@ -143,6 +166,12 @@ DEFAULT_OPTS = {
         # non-CLI
         'default': None
     },
+    'force': {
+        'default': False,
+        'opt': ['--force'],
+        'help': argparse.SUPPRESS,
+        'action': 'store_true'
+    },
     'group': {
         'default': None,
         'opt': ['--group'],
@@ -164,6 +193,12 @@ DEFAULT_OPTS = {
         'action': 'store_true',
         'group': 'debug'
     },
+    'list_specs': {
+        'default': False,
+        'opt': ['--list-specs'],
+        'help': 'Show insights-client collection specs',
+        'action': 'store_true'
+    },
     'logging_file': {
         'default': constants.default_log_file,
         'opt': ['--logging-file'],
@@ -370,45 +405,24 @@ DEFAULT_OPTS = {
     'payload': {
         'default': None,
         'opt': ['--payload'],
-        # 'help': 'Use Insights client to upload an archive',
-        'help': argparse.SUPPRESS,
+        'help': 'Use the Insights Client to upload an archive',
         'action': 'store',
         'group': 'platform'
     },
     'content_type': {
         'default': None,
         'opt': ['--content-type'],
-        # 'help': 'Content type of the archive specified with --payload',
-        'help': argparse.SUPPRESS,
+        'help': 'Content type of the archive specified with --payload',
         'action': 'store',
         'group': 'platform'
     },
     'diagnosis': {
         'default': None,
         'opt': ['--diagnosis'],
-        'help': argparse.SUPPRESS,
+        'help': 'Retrieve a diagnosis for this system',
         'const': True,
         'nargs': '?',
         'group': 'platform'
-    },
-    # AWS options
-    'portal_access': {
-        'default': False,
-        'opt': ['--portal-access'],
-        'group': 'platform',
-        'action': 'store_true',
-        'help': 'Entitle an AWS instance with Red Hat and register with Red Hat Insights'
-    },
-    'portal_access_no_insights': {
-        'default': False,
-        'opt': ['--portal-access-no-insights'],
-        'group': 'platform',
-        'action': 'store_true',
-        'help': 'Entitle an AWS instance with Red Hat, but do not register with Red Hat Insights'
-    },
-    'portal_access_hydra_url': {
-        # non-CLI
-        'default': constants.default_portal_access_hydra_url
     }
 }
 
@@ -429,6 +443,12 @@ class InsightsConfig(object):
 
         self._init_attrs = copy.copy(dir(self))
         self._update_dict(DEFAULT_KVS)
+
+        # initialize the real default for core_collect here
+        #   instead of inside DEFAULT_KVS because calling
+        #   this function at the module scope ignores unit test mocks
+        self.core_collect = _core_collect_default()
+
         if args:
             self._update_dict(args[0])
         self._update_dict(kwargs)
@@ -638,8 +658,6 @@ class InsightsConfig(object):
         if self.enable_schedule and self.disable_schedule:
             raise ValueError(
                 'Conflicting options: --enable-schedule and --disable-schedule')
-        if self.portal_access and self.portal_access_no_insights:
-            raise ValueError('Conflicting options: --portal-access and --portal-access-no-insights')
         if self.payload and not self.content_type:
             raise ValueError(
                 '--payload requires --content-type')
@@ -700,12 +718,12 @@ class InsightsConfig(object):
         self.keep_archive = self.keep_archive or self.no_upload
         if self.to_json and self.quiet:
             self.diagnosis = True
+        if self.test_connection:
+            self.net_debug = True
         if self.payload or self.diagnosis or self.compliance or self.show_results or self.check_results:
             self.legacy_upload = False
         if self.payload and (self.logging_file == constants.default_log_file):
             self.logging_file = constants.default_payload_log
-        if os.path.exists(constants.register_marker_file):
-            self.register = True
         if self.output_dir or self.output_file:
             # do not upload in this case
             self.no_upload = True
