@@ -8,10 +8,10 @@ import os
 import six
 import json
 import logging
-import pkg_resources
 import platform
 import xml.etree.ElementTree as ET
 import warnings
+import errno
 # import io
 from tempfile import TemporaryFile
 # from datetime import datetime, timedelta
@@ -173,6 +173,7 @@ class InsightsConnection(object):
         """
         Generates and returns a string suitable for use as a request user-agent
         """
+        import pkg_resources
         core_version = "insights-core"
         pkg = pkg_resources.working_set.find(pkg_resources.Requirement.parse(core_version))
         if pkg is not None:
@@ -315,7 +316,7 @@ class InsightsConnection(object):
         paths = (url.path + '/', '', '/r', '/r/insights')
         for ext in paths:
             try:
-                logger.debug("Testing: %s", test_url + ext)
+                logger.log(NETWORK, "Testing: %s", test_url + ext)
                 if method is "POST":
                     test_req = self.session.post(
                         test_url + ext, timeout=self.config.http_timeout, data=test_flag)
@@ -347,7 +348,7 @@ class InsightsConnection(object):
         if self.config.legacy_upload:
             return self._legacy_test_urls(url, method)
         try:
-            logger.debug('Testing %s', url)
+            logger.log(NETWORK, 'Testing %s', url)
             if method is 'POST':
                 test_tar = TemporaryFile(mode='rb', suffix='.tar.gz')
                 test_files = {
@@ -841,7 +842,7 @@ class InsightsConnection(object):
         logger.debug("Upload duration: %s", upload.elapsed)
         return upload
 
-    def upload_archive(self, data_collected, content_type, duration):
+    def upload_archive(self, data_collected, content_type, duration=None):
         """
         Do an HTTPS Upload of the archive
         """
@@ -880,7 +881,14 @@ class InsightsConnection(object):
             # 202 from platform, no json response
             logger.debug(upload.text)
             # upload = registration on platform
-            write_registered_file()
+            try:
+                write_registered_file()
+            except OSError as e:
+                if e.errno == errno.EACCES and os.getuid() != 0:
+                    # if permissions error as non-root, ignore
+                    pass
+                else:
+                    logger.error('Could not update local registration record: %s', str(e))
         else:
             logger.debug(
                 "Upload archive failed with status code %s",
