@@ -40,12 +40,11 @@ class InsightsConstants(object):
     insights_core_last_stable_gpg_sig = os.path.join(insights_core_lib_dir, 'last_stable.egg.asc')
     insights_core_newest = os.path.join(insights_core_lib_dir, 'newest.egg')
     insights_core_gpg_sig_newest = os.path.join(insights_core_lib_dir, 'newest.egg.asc')
+    module_router_path = "/module-update-router/v1/channel?module=insights-core"
     sig_kill_ok = 100
     sig_kill_bad = 101
     cached_branch_info = os.path.join(default_conf_dir, '.branch_info')
     pidfile = os.path.join(os.sep, 'var', 'run', 'insights-client.pid')
-    # this file is used to attempt registration when the client starts, implies --register
-    register_marker_file = os.path.join(os.sep, 'var', 'run', 'insights-client-try-register')
-    # default Hydra endpoint for posting entitlements information for AWS
-    default_portal_access_hydra_url = 'https://access.redhat.com/hydra/rest/accounts/entitle'
     valid_compressors = ("gz", "xz", "bz2", "none")
+    # RPM version in which core collection was released
+    core_collect_rpm_version = '3.1.0'
