@@ -11,6 +11,8 @@ import datetime
 import shlex
 import re
 import sys
+import threading
+import time
 from subprocess import Popen, PIPE, STDOUT
 
 import yaml
@@ -101,10 +103,6 @@ def delete_registered_file():
 def delete_unregistered_file():
     for f in constants.unregistered_files:
         write_to_disk(f, delete=True)
-    # this function only called when machine is registered,
-    #  so while registering, delete this file too. we only
-    #  need it around until we're registered
-    write_to_disk(constants.register_marker_file, delete=True)
 
 
 def delete_cache_files():
@@ -145,11 +143,14 @@ def generate_machine_id(new=False,
         logger.debug("Creating %s", destination_file)
         write_to_disk(destination_file, content=machine_id)
 
+    machine_id = str(machine_id).strip()
+
     try:
         uuid.UUID(machine_id, version=4)
-        return str(machine_id).strip()
-    except ValueError:
+        return machine_id
+    except ValueError as e:
         logger.error("Invalid machine ID: %s", machine_id)
+        logger.error("Error details: %s", str(e))
         logger.error("Remove %s and a new one will be generated.\nRerun the client with --register", destination_file)
         sys.exit(constants.sig_kill_bad)
 
@@ -294,28 +295,50 @@ def read_pidfile():
     return pid
 
 
-def systemd_notify(pid):
+def _systemd_notify(pid):
     '''
     Ping the systemd watchdog with the main PID so that
     the watchdog doesn't kill the process
     '''
-    if not os.getenv('NOTIFY_SOCKET'):
-        # running standalone, not via systemd job
-        return
+    try:
+        proc = Popen(['/usr/bin/systemd-notify', '--pid=' + str(pid), 'WATCHDOG=1'])
+    except OSError as e:
+        logger.debug('Could not launch systemd-notify: %s', str(e))
+        return False
+    stdout, stderr = proc.communicate()
+    if proc.returncode != 0:
+        logger.debug('systemd-notify returned %s', proc.returncode)
+        return False
+    return True
+
+
+def systemd_notify_init_thread():
+    '''
+    Use a thread to periodically ping systemd instead
+    of calling it on a per-command basis
+    '''
+    pid = read_pidfile()
     if not pid:
         logger.debug('No PID specified.')
         return
+    if not os.getenv('NOTIFY_SOCKET'):
+        # running standalone, not via systemd job
+        return
     if not os.path.exists('/usr/bin/systemd-notify'):
         # RHEL 6, no systemd
         return
-    try:
-        proc = Popen(['/usr/bin/systemd-notify', '--pid=' + str(pid), 'WATCHDOG=1'])
-    except OSError:
-        logger.debug('Could not launch systemd-notify.')
-        return
-    stdout, stderr = proc.communicate()
-    if proc.returncode != 0:
-        logger.debug('systemd-notify returned %s', proc.returncode)
+
+    def _sdnotify_loop():
+        while True:
+            # run sdnotify every 30 seconds
+            if not _systemd_notify(pid):
+                # end the loop if something goes wrong
+                break
+            time.sleep(30)
+
+    sdnotify_thread = threading.Thread(target=_sdnotify_loop, args=())
+    sdnotify_thread.daemon = True
+    sdnotify_thread.start()
 
 
 def get_tags(tags_file_path=constants.default_tags_file):
