@@ -175,6 +175,7 @@ class FileProvider(ContentProvider):
 
     def validate(self):
         if not blacklist.allow_file("/" + self.relative_path):
+            log.warning("WARNING: Skipping file %s", "/" + self.relative_path)
             raise dr.SkipComponent()
 
         if not os.path.exists(self.path):
@@ -313,6 +314,7 @@ class CommandOutputProvider(ContentProvider):
 
     def validate(self):
         if not blacklist.allow_command(self.cmd):
+            log.warning("WARNING: Skipping command %s", self.cmd)
             raise dr.SkipComponent()
 
         if not which(shlex.split(self.cmd)[0], env=self.create_env()):
@@ -379,7 +381,8 @@ class CommandOutputProvider(ContentProvider):
         args = self.create_args()
         fs.ensure_path(os.path.dirname(dst))
         if args:
-            p = Pipeline(*args, timeout=self.timeout, env=self.create_env())
+            timeout = self.timeout or self.ctx.timeout
+            p = Pipeline(*args, timeout=timeout, env=self.create_env())
             return p.write(dst, keep_rc=self.keep_rc)
 
     def __repr__(self):
