@@ -75,9 +75,11 @@ class Specs(SpecSet):
     cloud_init_log = RegistryPoint(filterable=True)
     cluster_conf = RegistryPoint(filterable=True)
     cmdline = RegistryPoint()
+    cni_podman_bridge_conf = RegistryPoint()
     cobbler_modules_conf = RegistryPoint()
     cobbler_settings = RegistryPoint()
     corosync = RegistryPoint()
+    corosync_cmapctl = RegistryPoint(multi_output=True)
     corosync_conf = RegistryPoint()
     cpe = RegistryPoint()
     cpu_cores = RegistryPoint(multi_output=True)
@@ -120,6 +122,7 @@ class Specs(SpecSet):
     dmesg_log = RegistryPoint(filterable=True)
     dmidecode = RegistryPoint()
     dmsetup_info = RegistryPoint()
+    dnf_conf = RegistryPoint(filterable=True)
     dnf_modules = RegistryPoint()
     dnf_module_list = RegistryPoint()
     dnf_module_info = RegistryPoint()
@@ -135,8 +138,10 @@ class Specs(SpecSet):
     docker_storage_setup = RegistryPoint()
     docker_sysconfig = RegistryPoint()
     dracut_kdump_capture_service = RegistryPoint()
+    du_dirs = RegistryPoint(multi_output=True)
     dumpe2fs_h = RegistryPoint(multi_output=True)
     engine_config_all = RegistryPoint()
+    engine_db_query_vdsm_version = RegistryPoint()
     engine_log = RegistryPoint(filterable=True)
     etc_journald_conf_d = RegistryPoint(multi_output=True)
     etc_journald_conf = RegistryPoint()
@@ -207,7 +212,6 @@ class Specs(SpecSet):
     hponcfg_g = RegistryPoint()
     httpd_access_log = RegistryPoint(filterable=True)
     httpd_conf = RegistryPoint(multi_output=True)
-    httpd_conf_sos = RegistryPoint(multi_output=True)
     httpd_conf_scl_httpd24 = RegistryPoint(multi_output=True)
     httpd_conf_scl_jbcs_httpd24 = RegistryPoint(multi_output=True)
     httpd_error_log = RegistryPoint(filterable=True)
@@ -216,7 +220,6 @@ class Specs(SpecSet):
     httpd_limits = RegistryPoint(multi_output=True)
     httpd_M = RegistryPoint(multi_output=True)
     httpd_on_nfs = RegistryPoint()
-    httpd_pid = RegistryPoint()
     httpd_ssl_access_log = RegistryPoint(filterable=True)
     httpd_ssl_error_log = RegistryPoint(filterable=True)
     httpd_V = RegistryPoint(multi_output=True)
@@ -225,6 +228,7 @@ class Specs(SpecSet):
     ifcfg_static_route = RegistryPoint(multi_output=True)
     ifconfig = RegistryPoint()
     imagemagick_policy = RegistryPoint(multi_output=True, filterable=True)
+    initctl_lst = RegistryPoint()
     init_ora = RegistryPoint()
     initscript = RegistryPoint(multi_output=True)
     init_process_cgroup = RegistryPoint()
@@ -304,6 +308,7 @@ class Specs(SpecSet):
     ls_var_spool_postfix_maildrop = RegistryPoint()
     ls_var_tmp = RegistryPoint(filterable=True)
     ls_var_www = RegistryPoint()
+    ls_tmp = RegistryPoint(filterable=True)
     lsblk = RegistryPoint()
     lsblk_pairs = RegistryPoint()
     lscpu = RegistryPoint()
@@ -314,8 +319,10 @@ class Specs(SpecSet):
     lspci = RegistryPoint()
     lssap = RegistryPoint()
     lsscsi = RegistryPoint()
+    lsvmbus = RegistryPoint()
     lvdisplay = RegistryPoint()
     lvm_conf = RegistryPoint(filterable=True)
+    lvmconfig = RegistryPoint()
     lvs_noheadings = RegistryPoint()
     lvs_noheadings_all = RegistryPoint()
     lvs = RegistryPoint()
@@ -339,7 +346,6 @@ class Specs(SpecSet):
     modinfo = RegistryPoint(multi_output=True)
     modinfo_all = RegistryPoint()
     modprobe = RegistryPoint(multi_output=True)
-    module = RegistryPoint()
     mongod_conf = RegistryPoint(multi_output=True, filterable=True)
     mount = RegistryPoint()
     mounts = RegistryPoint()
@@ -353,6 +359,7 @@ class Specs(SpecSet):
     mysql_log = RegistryPoint(multi_output=True, filterable=True)
     mysqld_limits = RegistryPoint()
     named_checkconf_p = RegistryPoint(filterable=True)
+    named_conf = RegistryPoint(filterable=True)
     namespace = RegistryPoint()
     ndctl_list_Ni = RegistryPoint()
     netconsole = RegistryPoint()
@@ -362,6 +369,7 @@ class Specs(SpecSet):
     netstat_s = RegistryPoint()
     networkmanager_dispatcher_d = RegistryPoint(multi_output=True)
     neutron_conf = RegistryPoint(filterable=True)
+    neutron_sriov_agent = RegistryPoint(filterable=True)
     neutron_dhcp_agent_ini = RegistryPoint(filterable=True)
     neutron_l3_agent_ini = RegistryPoint(filterable=True)
     neutron_l3_agent_log = RegistryPoint(filterable=True)
@@ -447,6 +455,7 @@ class Specs(SpecSet):
     passenger_status = RegistryPoint()
     password_auth = RegistryPoint()
     pci_rport_target_disk_paths = RegistryPoint()
+    pcp_metrics = RegistryPoint()
     pcs_config = RegistryPoint()
     pcs_quorum_status = RegistryPoint()
     pcs_status = RegistryPoint()
@@ -518,8 +527,9 @@ class Specs(SpecSet):
     route = RegistryPoint()
     rpm_V_packages = RegistryPoint()
     rsyslog_conf = RegistryPoint(filterable=True)
-    running_java = RegistryPoint()
     samba = RegistryPoint(filterable=True)
+    sap_dev_disp = RegistryPoint(multi_output=True, filterable=True)
+    sap_dev_rd = RegistryPoint(multi_output=True, filterable=True)
     sap_hdb_version = RegistryPoint(multi_output=True)
     sap_host_profile = RegistryPoint(filterable=True)
     sapcontrol_getsystemupdatelist = RegistryPoint()
@@ -541,7 +551,6 @@ class Specs(SpecSet):
     sealert = RegistryPoint()
     secure = RegistryPoint(filterable=True)
     selinux_config = RegistryPoint()
-    semid = RegistryPoint()
     sestatus = RegistryPoint()
     setup_named_chroot = RegistryPoint(filterable=True)
     smartctl = RegistryPoint(multi_output=True)
@@ -552,6 +561,7 @@ class Specs(SpecSet):
     softnet_stat = RegistryPoint()
     software_collections_list = RegistryPoint()
     spfile_ora = RegistryPoint(multi_output=True)
+    ssh_config_d = RegistryPoint(multi_output=True, filterable=True)
     ssh_config = RegistryPoint(filterable=True)
     ssh_foreman_config = RegistryPoint(filterable=True)
     ssh_foreman_proxy_config = RegistryPoint(filterable=True)
@@ -601,6 +611,7 @@ class Specs(SpecSet):
     systemctl_show_all_services = RegistryPoint()
     systemctl_show_target = RegistryPoint()
     systemctl_smartpdc = RegistryPoint()
+    systemd_analyze_blame = RegistryPoint()
     systemd_docker = RegistryPoint()
     systemd_logind_conf = RegistryPoint()
     systemd_openshift_node = RegistryPoint()
@@ -657,6 +668,7 @@ class Specs(SpecSet):
     xfs_info = RegistryPoint(multi_output=True)
     xinetd_conf = RegistryPoint(multi_output=True)
     yum_conf = RegistryPoint()
+    yum_list_available = RegistryPoint()
     yum_list_installed = RegistryPoint()
     yum_log = RegistryPoint()
     yum_repolist = RegistryPoint()
